# pytket-pyzx

[`pytket`](https://cqcl.github.io/pytket) is a Python module for interfacing
with CQC t|ket>, a set of quantum programming tools.

[PyZX](https://github.com/Quantomatic/pyzx) is an open-source Python library for
automated rewriting and optimisation of quantum circuits using the
[ZX-calculus](http://zxcalculus.com/).

`pytket_pyzx` is an extension to `pytket` that allows conversion to and from
PyZX representations.

## Getting started

`pytket_pyzx` is available for Python 3.6, 3.7 and 3.8, on Linux and MacOS. To
install, run:

```pip install pytket_pyzx```

## LICENCE

Copyright 2019-2020 Cambridge Quantum Computing

Licensed under a Non-Commercial Use Software Licence (the "Licence"); you may
not use this product except in compliance with the Licence. You may obtain a
copy of the Licence in the LICENCE file accompanying these documents or view
them [here](https://cqcl.github.io/pytket/build/html/licence.html).

Unless required by applicable law or agreed to in writing, software distributed
under the Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the Licence for the
specific language governing permissions and limitations under the Licence, but
note it is strictly for non-commercial use.
